acdp-cli-0.2.1 is not a library.
acdp-cli
Command-line client (acdp binary) for the Agent Context Distribution Protocol (ACDP)
Part of the acdp workspace — the reference
Rust implementation of the Agent Context Distribution Protocol (ACDP). Most
users should depend on the umbrella acdp crate, which
re-exports this crate under its historical module path.
License
Licensed under MIT OR Apache-2.0. See the workspace LICENSE.